# Upgrade steps from 6.12/6.13 to 7.0

See `doc/bc/changes-7.0.md` for requirements changes and deprecations.

## Stash cache usage changes

eZ Platform does no longer use Stash cache, so if you used this for custom logic you should
also migrate to use Symfony Cache.

### Config changes

SiteAccess aware setting `cache_pool_name` has been renamed to `cache_service_name` because it now
expects a service and not a Stash cache pool name. The cache service needs to be an instance of
`Symfony\Component\Cache\Adapter\AdapterInterface`.

General recommendation is to use FileSystem on single server _(default)_, and Redis for cluster.

For further reading on Symfony Cache see:
- https://symfony.com/doc/current/components/cache.html
- https://symfony.com/doc/current/reference/configuration/framework.html#reference-cache
- https://symfony.com/doc/current/components/cache/cache_pools.html

### Cache pool code changes

The `ezpublish.cache_pool` service is still a PSR-6 cache pool (`Psr\Cache\CacheItemPoolInterface`), so if you only use
that (type hint and usage), then you don't need to change your code.

*However* if you used Stash specific features you'll need to adapt to be able to:
- Continue to use cache service by eZ Platform
- Take advantage of the performance improvements offered by Symfony Cache
- Be able to clear eZ SPI Persistence cache which is now using this istead.

### Getting the cache pool
_If you can, then type hint using only `Psr\Cache\CacheItemPoolInterface`,
however this does not expose Symfony cache tagging feature._

Typically you would depend on this in your services, but for example sake:
```php
/** @var \Symfony\Component\Cache\Adapter\TagAwareAdapterInterface */
$pool = $container->get('ezpublish.cache_pool');
```

#### Cache pool usage for custom caching
```php
$cacheItem = $pool->getItem("myApp-object-${id}");
if ($cacheItem->isHit()) {
    return $cacheItem->get();
}

$myObject = $container->get('my_app.backend_service')->loadObject($id)
$cacheItem->set($myObject);
$cacheItem->tag(["myApp-category-${myObject->categoryId}"]);
$pool->save($cacheItem);

return $myObject;
```

How you use cache tagging is up to you, however typically you will use it to be able to efficiently clear
relevant cache without having to do lockups on all effected id's.

E.g. In the case of content type changes in eZ Platform all content cache of type article
can be cleared using tag.

For more info on usage, take a look at [Symfony Cache's documentation](https://symfony.com/doc/3.4/components/cache.html).

#### Cache pool usage for clearing eZ cache


```php
// To clear all cache (not recommended without a very good reason)
$pool->clear();

// To clear a specific cache item (check source for more examples in eZ\Publish\Core\Persistence\Cache\*)
$pool->deleteItems(["ez-content-info-$contentId"]);

// Symfony cache is tag-based, so you can clear all cache related to a specific Content item like this:
$pool->invalidateTags(["content-$contentId"])
```

_For full list of cache tags used by the system, see: `doc/specifications/cache/persistence/Readme.md`._


## Other relevant changes

- If you continue to use legacy, see: https://github.com/ezsystems/LegacyBridge/blob/master/doc/upgrade/2.0.md

- Symfony changes: https://symfony.com/doc/3.4/setup/upgrade_major.html

- If you extend Symfony it might also be worth checking full list of changes:
  https://github.com/symfony/symfony/blob/3.4/UPGRADE-3.0.md
  https://github.com/symfony/symfony/blob/3.4/UPGRADE-3.1.md
  https://github.com/symfony/symfony/blob/3.4/UPGRADE-3.3.md
  https://github.com/symfony/symfony/blob/3.4/UPGRADE-3.4.md
